---
layout: default
---

# Usage of hashit

Hashit takes arguments like this:
```bash
usage: hashit [-h] [-p] [-V] [-l] [-hl] [-H hashname]
              [-e excludes [excludes ...]] [-C] [-sp] [-A] [-q] [-m] [-r]
              [-s [string]] [-d [hash]] [-c filename] [-o filename] [-S]
              [-sfv] [-bsd] [--trace] [--strict]
              [path] [files [files ...]]
```

Where the options are at following:

[//]: # (Nicely generated by argparse)

```
Hashit is an hashing program which can be uses to hash and verify muliple
files on a system. I got the idea from an ubuntu iso image which have this
hash table, so i got the idea to make such a program using python.

positional arguments:
  path
  files

help:
  -h, --help            show this help message and exit
  -p, --page            Launch interactive help with python help() (for python
                        api)
  -V, --version         Print current version and exit
  -l, --license         Print license and exit
  -hl, --hash-list      Prints list of all supported hashes and exits

formats:
  -S, --size            Adds the file size to the output
  -sfv, --sfv           Outputs in a sfv compatible format
  -bsd, --bsd           output using the bsd checksum-format

settings:
  -H hashname, --hash hashname
                        Select hash use -hl --hash-list for more info
  -e excludes [excludes ...], --exclude excludes [excludes ...]
                        list of files and directories to exclude
  -C, --color           Enable colored output where it is supported
  -sp, --strip-path     Strips fullpath from the results
  -A, --append          Instead of writing to a file you will append to it
  -q, --quiet           Reduces output
  -m, --memory-optimatation
                        Enables memory optimatation (useful for large files)
  -r, --recursive       Hash all files in all subdirectories

other:
  -s [string], --string [string]
                        hash a string or a piece of text
  -d [hash], --detect [hash]
                        Enable hash detection for check
  -c filename, --check filename
                        Verify checksums from a checksum file
  -o filename, --output filename
                        output output to an output (file)

devtools:
  --trace               Print traceback of any error cathed and exit
  --strict              Exit non-zero on any errors

MIT, Copyrigth (c) 2017-2018 Javad Shafique
```

So if i want to hash a file called fx. icon.png
```bash
$ hashit icon.png
eade8f2bb7fcb89d396a850b977740fd  icon.png
```

Or i wanted to hash the tests directory with lets say blake2s and write it to a file using the bsd format and then verify it
```bash
$ hashit -H blake2s -o output.txt -bsd tests/
# no need to specify the files format it detects it automaticly
$ hashit -H blake2s -c output.txt -C # or --color for -C
tests/speed.py: OK
tests/test.py: OK
tests/__init__.py: OK
tests/speed2.py: OK
tests/res/benchmarks2.json: OK
tests/res/file.json: OK
tests/res/crc_hashcollisions.txt: OK
tests/res/benchmarks.json: OK
tests/res/pycrypto_vs_hashlib.json: OK
tests/__pycache__/speed.cpython-36.pyc: OK
tests/__pycache__/speed2.cpython-36.pyc: OK
tests/__pycache__/test.cpython-36.pyc: OK
tests/__pycache__/__init__.cpython-36.pyc: OK
```

But maybe you don't want to hash an file but a password or a piece of text then use the -s option
```bash
$ hashit -s secret_key
73eeac3fa1a0ce48f381ca1e6d71f077
# if you just use -s it will read until you use ctrl+D (^D) 
$ hashit -s
secret_key^D
73eeac3fa1a0ce48f381ca1e6d71f077
```
If you want to hash multiple files with forexample a wildcard(*):
```bash
$ hashit *.txt
d41d8cd98f00b204e9800998ecf8427e empty.txt
d41d8cd98f00b204e9800998ecf8427e another_0bytefile.txt
d41d8cd98f00b204e9800998ecf8427e no_data.txt
```


> TIP: add quotes around multi length strings to make them a single argument

## From python
It also got a python-level api for those you want to integrate this into your own application
```py
from hashit import hashFile, new

# init hashing class
hasher = new("md5")
hash_from_file = hashFile("file.txt", hasher, True) # (True) Activate memory optimatation, faster for larger files
print(hash_from_file)

print(new("sha3_256", b'DATA').hexdigest())
print(new("crc32", b'DATA').hexdigest()) # custom hashes is also supported
```
See [extra](extra.md) for more customization


[back](index.md)
